#ifndef __VIDEOFILE_LOAD_SW__
#define __VIDEOFILE_LOAD_SW__

////////////////////////////////////////////////////////////////////////////////////
//
// videofileload.h  
//
//  header file required for loading in video files created by the PITZ video system
//
////////////////////////////////////////////////////////////////////////////////////
//	created and modified by Stefan Weisse / DESY Zeuthen, November 2005
////////////////////////////////////////////////////////////////////////////////////

#include <videosystem3/platform.h>
#include <videosystem3/v2core.h>

#ifdef __cplusplus
extern "C" {
#endif 

// function prototypes

VIDEOSYSTEM3_API INT32	load_imm_file			( const char *filename, struct VIDINFHDR *vinf );
VIDEOSYSTEM3_API INT32	load_bkg_file			( const char *filename, struct VIDINFHDR *vinf );
VIDEOSYSTEM3_API INT32	load_imc_bkc_file		( const char *filename, struct VIDINFHDR *vinf, INT32 type);
VIDEOSYSTEM3_API INT32	load_imc_file			( const char *filename, struct VIDINFHDR *vinf );
VIDEOSYSTEM3_API INT32	load_bkc_file			( const char *filename, struct VIDINFHDR *vinf );
VIDEOSYSTEM3_API INT32	load_file			( INT32 type, const char *filename, struct VIDINFHDR *vinf );

// arbitrary, non-standard bkg file with multiple images
VIDEOSYSTEM3_API INT32	load_bkg_file_arb		( const char *filename, struct VIDINFHDR *vinf ); 

VIDEOSYSTEM3_API INT32	save_file			( INT32 type, const char *filename, const struct VIDINFHDR *vinf );
VIDEOSYSTEM3_API INT32	save_imm_file			( const char *outfilename, const struct VIDINFHDR *vinf );
VIDEOSYSTEM3_API INT32	save_bkg_file			( const char *outfilename, const struct VIDINFHDR *vinf );
VIDEOSYSTEM3_API INT32	save_bkc_file			( const char *outfilename, const struct VIDINFHDR *vinf );
VIDEOSYSTEM3_API INT32	save_imc_file			( const char *outfilename, const struct VIDINFHDR *vinf );
VIDEOSYSTEM3_API INT32	save_bmp_files( const char *base_filename, const struct VIDINFHDR *vinf, int fcol, int lzeroes);

// able to load in 8 bits per pixel (color table: 256 colors) video images as well as RGB24 bmp files
// vinf will return in any case 8 bits grayscale data (RGB24 image data will be downscaled (luminosity value) )
// 
// bEightBitDirect = 0 -> color table will be used and RGB24 will be created out of it, which
// will then be downscaled (luminosity value) to 8 bits per pixel
// bEightBitDirect = 1 -> 8 bits per pixel data will be directly loaded into 8 bits grayscale
VIDEOSYSTEM3_API INT32 load_bmp_file( const char *filename, struct VIDINFHDR *vinf, int aibEightBitDirect );

// SW Mar 19, 2013 added extended versions of saving possibly huge files START

INT32 save_imm_file_internal(   const char *filename, 
                                const struct VIDINFHDR *vinf,
                                int *apiInInterrupt,
                                double *apdOutPercentageFinished
                            );

INT32 save_imc_file_internal(   const char *filename, 
                                const struct VIDINFHDR *vinf,
                                int *apiInInterrupt,
                                double *apdOutPercentageFinished
                            );

INT32 save_bkc_file_internal(   const char *filename, 
                                const struct VIDINFHDR *vinf,
                                int *apiInInterrupt,
                                double *apdOutPercentageFinished
                            );

// SW Mar 19, 2013 added extended versions of saving possibly huge files END

#ifdef __cplusplus
}
#endif 


#endif  // __VIDEOFILE_LOAD_SW__
